summaryrefslogtreecommitdiffstats
path: root/src/sound/MappedStudio.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/sound/MappedStudio.h')
-rw-r--r--src/sound/MappedStudio.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/src/sound/MappedStudio.h b/src/sound/MappedStudio.h
index 89acc9b..e7fa4f9 100644
--- a/src/sound/MappedStudio.h
+++ b/src/sound/MappedStudio.h
@@ -71,14 +71,14 @@ public:
} MappedObjectType;
- MappedObject(MappedObject *parent,
+ MappedObject(MappedObject *tqparent,
const std::string &name,
MappedObjectType type,
MappedObjectId id):
m_type(type),
m_id(id),
m_name(name),
- m_parent(parent) {;}
+ m_tqparent(tqparent) {;}
virtual ~MappedObject() {;}
@@ -116,9 +116,9 @@ public:
// Ownership
//
- MappedObject* getParent() { return m_parent; }
- const MappedObject* getParent() const { return m_parent; }
- void setParent(MappedObject *parent) { m_parent = parent; }
+ MappedObject* getParent() { return m_tqparent; }
+ const MappedObject* getParent() const { return m_tqparent; }
+ void setParent(MappedObject *tqparent) { m_tqparent = tqparent; }
// Get a list of child ids - get a list of a certain type
//
@@ -135,7 +135,7 @@ public:
void destroy();
void destroyChildren();
- std::vector<MappedObject*> getChildObjects() { return m_children; }
+ std::vector<MappedObject*> getChildObjects() { return m_tqchildren; }
protected:
@@ -143,8 +143,8 @@ protected:
MappedObjectId m_id;
std::string m_name;
- MappedObject *m_parent;
- std::vector<MappedObject*> m_children;
+ MappedObject *m_tqparent;
+ std::vector<MappedObject*> m_tqchildren;
};
@@ -261,7 +261,7 @@ private:
MappedObjectId m_runningObjectId;
// All of our mapped (virtual) studio resides in this container as
// well as having all their parent/child relationships. Because
// some things are just blobs with no connections we need to
// maintain both - don't forget about this.
//
@@ -298,7 +298,7 @@ public:
Out
} ConnectionDirection;
- MappedConnectableObject(MappedObject *parent,
+ MappedConnectableObject(MappedObject *tqparent,
const std::string &name,
MappedObjectType type,
MappedObjectId id);
@@ -335,7 +335,7 @@ public:
static const MappedObjectProperty Pan;
static const MappedObjectProperty InputChannel;
- MappedAudioFader(MappedObject *parent,
+ MappedAudioFader(MappedObject *tqparent,
MappedObjectId id,
MappedObjectValue channels = 2); // stereo default
~MappedAudioFader();
@@ -385,7 +385,7 @@ public:
static const MappedObjectProperty Pan;
static const MappedObjectProperty Level;
- MappedAudioBuss(MappedObject *parent,
+ MappedAudioBuss(MappedObject *tqparent,
MappedObjectId id);
~MappedAudioBuss();
@@ -418,7 +418,7 @@ public:
static const MappedObjectProperty InputNumber;
- MappedAudioInput(MappedObject *parent,
+ MappedAudioInput(MappedObject *tqparent,
MappedObjectId id);
~MappedAudioInput();
@@ -455,7 +455,7 @@ public:
static const MappedObjectProperty Bypassed;
static const MappedObjectProperty Configuration; // list property
- MappedPluginSlot(MappedObject *parent, MappedObjectId id);
+ MappedPluginSlot(MappedObject *tqparent, MappedObjectId id);
~MappedPluginSlot();
virtual MappedObjectPropertyList getPropertyList(
@@ -513,7 +513,7 @@ public:
static const MappedObjectProperty DisplayHint;
static const MappedObjectProperty Value;
- MappedPluginPort(MappedObject *parent, MappedObjectId id);
+ MappedPluginPort(MappedObject *tqparent, MappedObjectId id);
~MappedPluginPort();
virtual MappedObjectPropertyList getPropertyList(
@@ -261,7 +261,7 @@ private:
MappedObjectId m_runningObjectId;
// All of our mapped (virtual) studio resides in this container as
- // well as having all their parent/child relationships. Because
+ // well as having all their tqparent/child relationships. Because
// some things are just blobs with no connections we need to
// maintain both - don't forget about this.